/*
 * mkfifo.c
 */


#include<sys/types.h>
#include<fcntl.h>


int mkfifo(const char *pathname, mode_t mode)
{
	int fd;

	fd = open(pathname, O_WRONLY | O_CREAT | O_EXCL | O_FIFO, mode);
	if (fd == -1) {
		return -1;
	}
	close(fd);

	return 0;
}
